<template>
  <el-dialog
    v-diadrag
    width="60%"
    title="零件"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="stock-part-dialog"
  >
    <ttable
      :table="table"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="350"
      :ajaxFun="ajaxFun"
      :paramObj="paramObj"
      ref="stockPartTable"
    >
      <template #toolbar></template>
    </ttable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>
<script>
import { getStock } from '@/api/product/personboard'
import ttable from '@/views/common/ztt-table'
import { remote } from '@/api/admin/dict'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data() {
    return {
      ajaxFun: getStock,
      innerVisible: false,
      currentRow: null,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'splitStock',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            width: '100',
            minWidth: '100',
            prop: 'partNo',
            label: '零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'warehouseName',
            label: '仓库',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'locationName',
            label: '库位号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'systemNo',
            label: '系统编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'partBatchNo',
            label: '零件批号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'stockQuantity',
            label: '库存数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'reserveQuantity',
            label: '预留数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '120',
            prop: 'availableStockQuantity',
            label: '可用库存数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'unit',
            label: '单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ]
      }
    }
  },
  components: {
    ttable
  },
  methods: {
    saveSelectRow() {
      this.$emit('listenToStockEvent', this.currentRow)
      this.innerVisible = false
    },
    handleCurrentChange(row) {
      this.currentRow = row
    },
    getData() {
      if (this.$refs.stockPartTable !== undefined) {
        this.$refs.stockPartTable.getDataList()
      }
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    }
  },
  mounted() {}
}
</script>
<style>
.stock-part-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.stock-part-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.stock-part-dialog .el-dialog__body {
  padding: 5px 20px;
}

.stock-part-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.stock-part-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
